@@ -22,20 +22,6 @@ def get_file_map(inventory, version_dir):
     return file_map
 
 
-def is_valid_logical_path(path):
-    """True if the logical path is valid, False otherwise.
-
-    Neither a leading or trailing slash is allowed which is caught by the
-    split and then test for empty.
-
-    FIXME - https://github.com/OCFL/spec/issues/436
-    """
-    for element in path.split('/'):
-        if element in ['.', '..', '']:
-            return False
-    return True
-
-
 class InventoryValidator(object):
     """Class for OCFL Inventory Validator."""
 
@@ -48,9 +34,9 @@ class InventoryValidator(object):
         self.inventory = None
         self.digest_algorithm = 'sha512'
         self.content_directory = 'content'
-        self.head = None
         self.all_versions = []
         self.manifest_files = None
+        self.head = 'UNKNOWN'
         # Validation control
         self.lax_digests = lax_digests
 
@@ -106,7 +92,7 @@ class InventoryValidator(object):
             self.all_versions = self.validate_version_sequence(inventory['versions'])
             digests_used = self.validate_versions(inventory['versions'], self.all_versions)
         if 'head' in inventory:
-            self.head = self.all_versions[-1]
+            self.head = 'THERE_ARE_NO_VERSIONS' if len(self.all_versions) == 0 else self.all_versions[-1]
             if inventory['head'] != self.head:
                 self.error("E040", got=inventory['head'], expected=self.head)
         else:
@@ -153,7 +139,10 @@ class InventoryValidator(object):
         """
         all_versions = []
         if type(versions) != dict:
-            self.error('E044')
+            self.error("E044")
+            return all_versions
+        elif len(versions) == 0:
+            self.error("E008b")
             return all_versions
         # Validate version sequence
         # https://ocfl.io/draft/spec/#version-directories
@@ -173,7 +162,7 @@ class InventoryValidator(object):
                     max_version_num = (10 ** (n - 1)) - 1
                     break
             if not zero_padded:
-                self.error("E008")
+                self.error("E008a")
                 return all_versions
         if zero_padded:
             self.warn("W001")
@@ -231,7 +220,7 @@ class InventoryValidator(object):
             if 'message' not in version:
                 self.warn('W007a', version=v)
             elif type(version['message']) != str:
-                self.error('E048b', version=v)  # FIXME https://github.com/OCFL/spec/issues/460
+                self.error('E048b', version=v)
             if 'user' not in version:
                 self.warn('W007b', version=v)
             else:
@@ -257,6 +246,8 @@ class InventoryValidator(object):
         Returns a list of content digests referenced in the state block.
         """
         digests = []
+        logical_paths = set()
+        logical_directories = set()
         if type(state) != dict:
             self.error('E050c', version=version)
         else:
@@ -268,7 +259,7 @@ class InventoryValidator(object):
                     self.error('E050e', version=version, digest=digest)
                 else:
                     for path in state[digest]:
-                        if not is_valid_logical_path(path):
+                        if not self.check_logical_path(path, logical_paths, logical_directories):
                             self.error('E051', version=version, digest=digest, path=path)
                     norm_digest = normalized_digest(digest, self.digest_algorithm)
                     if norm_digest in digests:
@@ -276,8 +267,31 @@ class InventoryValidator(object):
                         self.error("E923", version=version, digest=norm_digest)
                     else:
                         digests.append(norm_digest)
+            # Check for conflicting logical paths
+            for path in logical_directories:
+                if path in logical_paths:
+                    self.error("E095", version=version, path=path)
         return digests
 
+    def check_logical_path(self, path, logical_paths, logical_directories):
+        """Check logical path and accumulate paths/directories for E095 check.
+
+        Neither a leading or trailing slash is allowed which is caught by the
+        split and then test for empty.
+
+        logical_paths and logical_directories are expected to sets.
+        """
+        valid = True
+        elements = path.split('/')
+        for element in elements:
+            if element in ['.', '..', '']:
+                valid = False
+                break
+        # Accumulate paths and directories
+        logical_paths.add(path)
+        logical_directories.add('/'.join(elements[0:-1]))
+        return valid
+
     def check_digests_present_and_used(self, manifest_files, digests_used):
         """Check all digests in manifest that are needed are present and used."""
         in_manifest = set(manifest_files.values())
@@ -301,8 +315,13 @@ class InventoryValidator(object):
 
     def is_valid_content_path(self, path):
         """True if path is a valid content path."""
-        m = re.match(r'''^v\d+/''' + self.content_directory + r'''/''', path)
-        return m is not None
+        m = re.match(r'''^v\d+/''' + self.content_directory + r'''/(.*)''', path)
+        if not m:
+            return False
+        for element in m.group(1).split('/'):
+            if element in ('', '.', '..'):
+                return False
+        return True
 
     def validate_as_prior_version(self, prior):
         """Check that prior is a valid InventoryValidator for a prior version of the current inventory object.
@@ -310,10 +329,8 @@ class InventoryValidator(object):
         Both inventories are assumed to have been checked for internal consistency.
         """
         # Must have a subset of versions which also check zero padding format etc.
-        if not set(prior.all_versions).issubset(set(self.all_versions)):
+        if not set(prior.all_versions) < set(self.all_versions):
             self.error('E066a', prior_head=prior.head)
-        elif not set(prior.manifest_files.keys()).issubset(self.manifest_files.keys()):
-            self.error('E066b', prior_head=prior.head)
         else:
             # Check references to files but realize that there might be different
             # digest algorithms between versions
@@ -321,12 +338,12 @@ class InventoryValidator(object):
                 prior_map = get_file_map(prior.inventory, version_dir)
                 self_map = get_file_map(self.inventory, version_dir)
                 if prior_map.keys() != self_map.keys():
-                    self.error('E066c', version_dir=version_dir, prior_head=prior.head)
+                    self.error('E066b', version_dir=version_dir, prior_head=prior.head)
                 else:
                     # Check them all...
                     for file in prior_map:
                         if prior_map[file] != self_map[file]:
-                            self.error('E066d', version_dir=version_dir, prior_head=prior.head, file=file)
+                            self.error('E066c', version_dir=version_dir, prior_head=prior.head, file=file)
             # Check metadata
             prior_version = prior.inventory['versions'][version_dir]
             self_version = self.inventory['versions'][version_dir]
