@@ -18,6 +18,12 @@ from .validation_logger import ValidationLogger
 from .w3c_datetime import str_to_datetime
 
 
+class ValidatorAbortException(Exception):
+    """Exception class to bail out of validation."""
+
+    pass
+
+
 class Validator(object):
     """Class for OCFL Validator."""
 
@@ -67,18 +73,21 @@ class Validator(object):
         if not os.path.exists(inv_file):
             self.log.error('E034')
             return False
-        inventory, inv_validator = self.validate_inventory(inv_file)
-        self.root_inv_validator = inv_validator
-        all_versions = inv_validator.all_versions
-        self.content_directory = inv_validator.content_directory
-        self.digest_algorithm = inv_validator.digest_algorithm
-        self.validate_inventory_digest(inv_file, self.digest_algorithm)
-        # Object root
-        self.validate_object_root(path, all_versions)
-        # Version inventory files
-        self.validate_version_inventories(path, inventory, all_versions)
-        # Object content
-        self.validate_content(path, inventory, all_versions)
+        try:
+            inventory, inv_validator = self.validate_inventory(inv_file)
+            self.root_inv_validator = inv_validator
+            all_versions = inv_validator.all_versions
+            self.content_directory = inv_validator.content_directory
+            self.digest_algorithm = inv_validator.digest_algorithm
+            self.validate_inventory_digest(inv_file, self.digest_algorithm)
+            # Object root
+            self.validate_object_root(path, all_versions)
+            # Version inventory files
+            self.validate_version_inventories(path, inventory, all_versions)
+            # Object content
+            self.validate_content(path, inventory, all_versions)
+        except ValidatorAbortException:
+            pass
         return self.log.num_errors == 0
 
     def validate_inventory(self, inv_file, where='root'):
@@ -88,8 +97,12 @@ class Validator(object):
         of object content. Does not look at anything else in the
         object itself.
         """
-        with open(inv_file) as fh:
-            inventory = json.load(fh)
+        try:
+            with open(inv_file) as fh:
+                inventory = json.load(fh)
+        except json.decoder.JSONDecodeError as e:
+            self.log.error('E033', where=where, explanation=str(e))
+            raise ValidatorAbortException
         inv_validator = InventoryValidator(log=self.log, where=where,
                                            lax_digests=self.lax_digests)
         inv_validator.validate(inventory)
@@ -150,9 +163,11 @@ class Validator(object):
     def validate_extensions_dir(self, path):
         """Validate content of extensions directory inside object root at path.
 
-        So far this is just to check that there aren't any entries in the
-        extensions directory that aren't directories themselves. Should refine/check
-        when https://github.com/OCFL/spec/issues/403 is resolved.
+        Validate the extensions directory by checking that there aren't any
+        entries in the extensions directory that aren't directories themselves.
+        Where there are extension directories they SHOULD be registered and
+        this code relies up the registered_extensions property to list known
+        extensions.
         """
         extpath = os.path.join(path, 'extensions')
         for entry in os.listdir(extpath):
@@ -165,6 +180,8 @@ class Validator(object):
 
     def validate_version_inventories(self, path, inventory, version_dirs):
         """Each version SHOULD have an inventory up to that point."""
+        if len(version_dirs) == 0:
+            return
         inv_digest_files = {}  # index by version_dir
         last_version = version_dirs[-1]
         for version_dir in version_dirs:
@@ -232,16 +249,17 @@ class Validator(object):
                     else:
                         self.log.error("E015", where=version_dir, entry=entry)
         # Check all files in root manifest
-        for digest in inventory['manifest']:
-            for filepath in inventory['manifest'][digest]:
-                if filepath not in files_seen:
-                    self.log.error('E023a', where='root', content_path=filepath)
-                else:
-                    if self.check_digests:
-                        content_digest = file_digest(os.path.join(path, filepath), digest_type=self.digest_algorithm)
-                        if content_digest != normalized_digest(digest, digest_type=self.digest_algorithm):
-                            self.log.error('E093', where='root', digest=digest, content_path=filepath, content_digest=content_digest)
-                    files_seen.discard(filepath)
+        if 'manifest' in inventory:
+            for digest in inventory['manifest']:
+                for filepath in inventory['manifest'][digest]:
+                    if filepath not in files_seen:
+                        self.log.error('E023a', where='root', content_path=filepath)
+                    else:
+                        if self.check_digests:
+                            content_digest = file_digest(os.path.join(path, filepath), digest_type=self.digest_algorithm)
+                            if content_digest != normalized_digest(digest, digest_type=self.digest_algorithm):
+                                self.log.error('E093', where='root', digest=digest, content_path=filepath, content_digest=content_digest)
+                        files_seen.discard(filepath)
         # Anything left in files_seen is not mentioned in the inventory
         if len(files_seen) > 0:
             self.log.error('E023b', where='root', extra_files=', '.join(sorted(files_seen)))
